library(psych)
library(ggplot2)
library(MASS)
library(grid)
library(boot)

setwd("wherever you put the csv files")


#### Study 1: Fall Semester ####

e1 <- read.csv("study 1.csv", header=T)

# score CRT
e1$CRT1Corr <- ifelse(e1$CRT1 == 5, 1, 0)
e1$CRT2Corr <- ifelse(e1$CRT2 == 5, 1, 0)
e1$CRT3Corr <- ifelse(e1$CRT3 == 47, 1, 0)
e1$CRT <- e1$CRT1Corr + e1$CRT2Corr + e1$CRT3Corr



e1 = subset(e1, Ev1 > -100 & CRT > -100)
nrow(e1)
summary(e1)


# some quick descriptives
describe(e1$Age)
describe(e1$BiG)
describe(e1$CRT)


#### Look at first evolution item ####


Ev1.log <- glm(Ev1 ~ CRT , data=e1, family="binomial")
summary(Ev1.log)
exp(coef(Ev1.log))
exp(confint(Ev1.log))



### Add in covariates


Ev1Full.log <- glm(Ev1 ~ CRT + BiG + RaisedRel + Conservative, data=e1, family="binomial")
summary(Ev1Full.log)
exp(coef(Ev1Full.log))
exp(confint(Ev1Full.log))


#### Look at second evolution item ####


Ev2.log <- glm(Ev2 ~ CRT , data=e1, family="binomial")
summary(Ev2.log)
exp(coef(Ev2.log))
exp(confint(Ev2.log))


### Add in covariates


Ev2Full.log <- glm(Ev2 ~ CRT + BiG + RaisedRel + Conservative, data=e1, family="binomial")
summary(Ev2Full.log)
exp(coef(Ev2Full.log))
exp(confint(Ev2Full.log))


#### Create Some Plots ####

### Ev1 within each CRT group




C0 <- subset(e1, CRT == 0)
C1 <- subset(e1, CRT == 1)
C2 <- subset(e1, CRT == 2)
C3 <- subset(e1, CRT == 3)



C0N <- describe(C0$Ev1)
C0Ev <- subset(C0, Ev1==1)
C0EvE <- describe(C0Ev$Ev1)
binom.test(C0EvE$n, C0N$n, p=.5)


C1N <- describe(C1$Ev1)
C1Ev <- subset(C1, Ev1==1)
C1EvE <- describe(C1Ev$Ev1)
binom.test(C1EvE$n, C1N$n, p=.5)

C2N <- describe(C2$Ev1)
C2Ev <- subset(C2, Ev1==1)
C2EvE <- describe(C2Ev$Ev1)
binom.test(C2EvE$n, C2N$n, p=.5)

C3N <- describe(C3$Ev1)
C3Ev <- subset(C3, Ev1==1)
C3EvE <- describe(C3Ev$Ev1)
binom.test(C3EvE$n, C3N$n, p=.5)

describeBy(e1$BiG, e1$CRT)

## Main Results Plot

Analytic <- c("0", "1", "2", "3")
Ev <- c(.66, .75, .76, .80)
lb <- c(.62, .66, .65, .70)
ub <- c(.71, .82, .85, .88)
God <- c(5.98, 5.9, 5.89, 5.31)
dat <- data.frame(Analytic, Ev, lb, ub, God)
dat


ggplot(data=dat, aes(x= Analytic, y = Ev, ymin = lb, ymax=ub))  + geom_pointrange( size=.8)  +  labs(x= "\nCorrect CRT Responses", y = "Proportion Endorsing Evolution\n") + theme_bw() +  scale_y_continuous(breaks = c(.5, .6, .7, .8, .9, 1), limits=c(.48, 1))




### Rescore for ordinal logistic regression

e1$evCat = c()

e1$evCat[e1$Ev1 == 0] <- "Young earth creationism"
e1$evCat[e1$Ev2 == 1] <- "Evolution"
e1$evCat[e1$Ev2 == 0] <- "Guided evolution"


t1 <- table(e1$evCat)
prop.table(t1)


g.1 <- e1[c("CRT", "evCat")]

summary(g.1)


t1 <- table(g.1$CRT, g.1$evCat)
g1 <- data.frame(prop.table(t1, 1))


g1$Beliefs <- g1$Var2





summary(g1)

ggplot(g1, aes(x=Var1, y=Freq, fill=Beliefs)) + 
  theme_bw() +
  geom_bar(stat="identity") + 
  guides(fill=guide_legend(reverse=T)) + 
  scale_fill_manual(values=c("black", "darkgrey", "lightgrey")) +
  labs(y="Proportion\n", x= "\nCorrect CRT Items")


#### ordinal logistic regression

e1$evCat <- factor(e1$evCat, levels = c("Young earth creationism", "Guided evolution", "Evolution"))

or1 <- polr(evCat ~ CRT, data=e1)
summary(or1)
confint(or1)


exp(coef(or1))
exp(confint(or1))


ctable <- coef(summary(or1))
p <- pnorm(abs(ctable[, "t value"]), lower.tail = FALSE) * 2

(ctable <- cbind(ctable, "p value" = p))



# now with covariates
or2 <- polr(evCat ~ CRT + BiG + RaisedRel + Conservative, data=e1)
summary(or2)
confint(or2)

exp(coef(or2))
exp(confint(or2))



ctable <- coef(summary(or2))
p <- pnorm(abs(ctable[, "t value"]), lower.tail = FALSE) * 2

(ctable <- cbind(ctable, "p value" = p))



## check to see if crt interacts with upbringing


or3 <- polr(evCat ~ CRT *  RaisedRel + BiG  + Conservative, data=e1)
summary(or3)
confint(or3)

exp(coef(or3))
exp(confint(or3))



ctable <- coef(summary(or3))
p <- pnorm(abs(ctable[, "t value"]), lower.tail = FALSE) * 2

## combined table
(ctable <- cbind(ctable, "p value" = p))






### combined plot for Figure 1


p1.1 <- ggplot(data=dat, aes(x= Analytic, y = Ev, ymin = lb, ymax=ub))  + 
  geom_pointrange( size=.8)  +  
  labs(x= "\nCorrect CRT Responses", y = "Proportion Endorsing Evolution\n", title="1A") + 
  theme_bw() +  
  scale_y_continuous(breaks = c(.5, .6, .7, .8, .9, 1), limits=c(.48, 1))

p1.2 <- ggplot(g1, aes(x=Var1, y=Freq, fill=Beliefs)) + 
  theme_bw() +
  geom_bar(stat="identity") + 
  guides(fill=guide_legend(reverse=T)) + 
  scale_fill_manual(name = "Belief:   ", values=c("black", "darkgrey", "lightgrey"), labels=c("Natural\nEvolution ","Guided\nEvolution ", "Creationism" )) +
  labs(y="Proportion\n", x= "\nCorrect CRT Responses", title= "1B") +
  theme(legend.position="top") 




pushViewport(viewport(layout = grid.layout(1, 2)))
print(p1.1, vp = viewport(layout.pos.row = 1, layout.pos.col = 1))
print(p1.2, vp = viewport(layout.pos.row = 1, layout.pos.col = 2))



## CRT belief plot (Fig 2)

ggplot(e1, aes(x=CRT, y=BiG)) +
  theme_bw() +
  geom_point(position=position_jitter(width=.3, height=.3), color="black", alpha=.4) +
  stat_smooth(method=lm, se=F, color="black") +
  labs(x= "\nCorrect CRT Items", y = "Belief in God (1-7)\n") +
  scale_y_continuous(breaks = c(1, 2, 3, 4, 5, 6, 7), limits=c(1, 7))


# does CRT predict belief in God?
e1$BiGz = scale(e1$BiG, scale=T, center=T)
e1$crtz = scale(e1$CRT, scale=T, center=T)

e1.rel = lm(BiGz ~crtz, data=e1)
summary(e1.rel)
confint(e1.rel)



## bootstrap model coefficients for CRT- belief
bs <- function(formula, data, indices) {
  d <- data[indices,] # allows boot to select sample 
  fit <- lm(formula, data=d)
  return(coef(fit)) 
} 

results <- boot(data=e1, statistic=bs, 
                R=10000, formula=BiGz ~ crtz)

# view results
results
plot(results, index=2) 


# get 95% confidence intervals 

boot.ci(results, type="perc", index=2) 





#### Plot comparing UK data to Pew data ####


binom.test(sum(e1$Ev1), nrow(e1), p=.5)

table(e1$Creationism)

Data <- c("Kentucky", "Kentucky", "Pew", "Pew" )
Belief <- c("Creationism", "Evolution", "Creationism", "Evolution")
p <- c(.293, 1-.293, .33, .60)
lb <- c(.264, 1-.324, .30, .57)
ub <- c(.324, 1-.264, .36, .63)
dat2 <- data.frame(Data, Belief, p, lb, ub)
dat2




ggplot(data=dat2, aes(x= Belief, y = p, ymin = lb, ymax=ub)) + 
  theme_bw()  + 
  geom_pointrange( size=1, aes(color=Data), position=position_dodge(width=c(0.2,0.2)), shape=16) +
  labs(x= "\nOrigins Belief", y = "Proportion Errors\n") +
  scale_color_grey()  +
  theme(legend.position=c(.5, .86)) +
  theme(legend.key = element_blank()) +
  scale_y_continuous(limits=c(0,1))




#### Study 2: Spring Semester ####

e2 <- read.csv("study 2.csv", header=T)
e2 = subset(e2, Fall == 0)  # drop people who participated in the fall survey



## Calculate CRT


e2$CRT1 <- ifelse(e2$CRT1 == .05, 1, 0)
e2$CRT2 <- ifelse(e2$CRT2 == 5, 1, 0)
e2$CRT3 <- ifelse(e2$CRT3 == 47, 1, 0)
e2$CRT  <- e2$CRT1 + e2$CRT2 + e2$CRT3





## Calculate Creds

c = e2[c(9:15)]
summary(c)

alpha(c)

e2$CRED <- (e2$CRED1 +e2$CRED2 +e2$CRED3 + e2$CRED4 + e2$CRED5 + e2$CRED6 + e2$CRED7)/7


## Get people who completed CRT and Ev

e2 = subset(e2, CRT > -500 & EvN > -500)

summary(e2)

#some quick descriptives
nrow(e2)
describe(e2$Age)
describe(e2$BiG100)
describe(e2$CRT)

#### work out some ordinal stats. check plot first
t <- table(e2$Ev)
prop.table(t)


g <- e2[c("CRT", "Ev")]

summary(g)


t2 <- table(g$CRT, g$Ev)
g2 <- data.frame(prop.table(t2, 1))


g2$Beliefs <- g2$Var2

summary(g2)

ggplot(g2, aes(x=Var1, y=Freq, fill=Beliefs)) + 
  theme_bw() +
  geom_bar(stat="identity") + 
  guides(fill=guide_legend(reverse=T)) + 
  scale_fill_manual(values=c("black", "darkgrey", "lightgrey")) +
  labs(y="Proportion\n", x= "\nCorrect CRT Items")



### Try some ordered regression


e2$Ev <- factor(e2$Ev, levels = c("Young earth creationism", "Guided evolution", "Evolution"))

or1 <- polr(Ev ~ CRT, data=e2)
summary(or1)
confint(or1)


exp(coef(or1))
exp(confint(or1))


ctable <- coef(summary(or1))
p <- pnorm(abs(ctable[, "t value"]), lower.tail = FALSE) * 2

## combined table
(ctable <- cbind(ctable, "p value" = p))





##### add covariates


or2 <- polr(Ev ~ CRT + CRED + BiG100  + AttendN, data=e2)
summary(or2)
confint(or2)

exp(coef(or2))
exp(confint(or2))



ctable <- coef(summary(or2))
p <- pnorm(abs(ctable[, "t value"]), lower.tail = FALSE) * 2

## combined table
(ctable <- cbind(ctable, "p value" = p))



### try to mimic study 1's breakdown

## parse out evolution vs. YEC

e2$ev1 = ifelse(e2$Ev != "Young earth creationism", 1, 0)
summary(e2)

e2ev = subset(e2, ev1 == 1)
summary(e2ev)


yec = glm(ev1 ~ CRT, data=e2, family="binomial")
summary(yec)
exp(coef(yec))
exp(confint(yec))


evtype = glm(Ev ~ CRT, data=e2ev, family="binomial")
summary(evtype)
exp(coef(evtype))
exp(confint(evtype))


yec2 = glm(ev1 ~ CRT + BiG100 + CRED + AttendN, data=e2, family="binomial")
summary(yec2)
exp(coef(yec2))
exp(confint(yec2))


evtype2 = glm(Ev ~ CRT + BiG100 + CRED + AttendN, data=e2ev, family="binomial")
summary(evtype2)
exp(coef(evtype2))
exp(confint(evtype2))



## graph like study 1

# get probabilities

c0 = subset(e2, CRT == 0)
c1 = subset(e2, CRT == 1)
c2 = subset(e2, CRT == 2)
c3 = subset(e2, CRT == 3)




binom.test(sum(c0$ev1, na.rm=T), nrow(c0))
binom.test(sum(c1$ev1, na.rm=T), nrow(c1))
binom.test(sum(c2$ev1, na.rm=T), nrow(c2))
binom.test(sum(c3$ev1, na.rm=T), nrow(c3))

Analytic2 <- c("0", "1", "2", "3")
Ev2 <- c(.58, .75, .74, .72)
lb2 <- c(.52, .66, .62, .60)
ub2 <- c(.63, .83, .83, .83)
dat2 <- data.frame(Analytic2, Ev2, lb2, ub2)
dat2


ggplot(data=dat2, aes(x= Analytic2, y = Ev2, ymin = lb2, ymax=ub2))  + geom_pointrange( size=.8)  +  labs(x= "\nCorrect CRT Responses", y = "Proportion Endorsing Evolution\n") + theme_bw() +  scale_y_continuous(breaks = c(.5, .6, .7, .8, .9, 1), limits=c(.48, 1))





## Combined Graph (Fig 3)


p2.1 <- ggplot(data=dat2, aes(x= Analytic2, y = Ev2, ymin = lb2, ymax=ub2))  + 
  geom_pointrange( size=.8)  +  
  labs(x= "\nCorrect CRT Responses", y = "Proportion Endorsing Evolution\n", title="3B") + 
  theme_bw() +  
  scale_y_continuous(breaks = c(.5, .6, .7, .8, .9, 1), limits=c(.48, 1))

p2.2 <- ggplot(g2, aes(x=Var1, y=Freq, fill=Beliefs)) + 
  theme_bw() +
  geom_bar(stat="identity") + 
  guides(fill=guide_legend(reverse=T)) + 
  scale_fill_manual(name = "Belief:   ", values=c("black", "darkgrey", "lightgrey"), labels=c("Natural\nEvolution ","Guided\nEvolution ", "Creationism" )) +
  labs(y="Proportion\n", x= "\nCorrect CRT Responses", title= "3A") +
  theme(legend.position="top") 




pushViewport(viewport(layout = grid.layout(1, 2)))
print(p2.2, vp = viewport(layout.pos.row = 1, layout.pos.col = 1))
print(p2.1, vp = viewport(layout.pos.row = 1, layout.pos.col = 2))


## CRT-belief in God analyses and plot (Fig 4)

ggplot(e2, aes(x=CRT, y=BiG100)) +
  theme_bw() +
  geom_point(position=position_jitter(width=.3, height=2), color="black", alpha=.4) +
  stat_smooth(method=lm, se=F, color="black") +
  labs(x= "\nCorrect CRT Items", y = "Belief in God (0-100)\n") +
  scale_y_continuous(breaks = c(0, 25, 50, 75, 100), limits=c(0, 100))

e2$BiGz = scale(e2$BiG100, scale=T, center=T)
e2$crtz = scale(e2$CRT, scale=T, center=T)

e2.rel = lm(BiGz ~crtz, data=e2)
summary(e2.rel)
confint(e2.rel)


bs <- function(formula, data, indices) {
  d <- data[indices,] # allows boot to select sample 
  fit <- lm(formula, data=d)
  return(coef(fit)) 
} 
# bootstrapping with 1000 replications 
results <- boot(data=e2, statistic=bs, 
                R=10000, formula=BiGz ~ crtz)

# view results
results
plot(results, index=2) # wt 


# get 95% confidence intervals 

boot.ci(results, type="perc", index=2) # wt 



